/*
----------------------------------------------------------------------

	AdAstra - Real Time Kernel

	Alain Chebrou

	SystemClock_Config.c		The function to initialize MCU clocks

	When		Who	What
	21/01/20	ac	created
	05/07/21	ac	Remove LSE enable

----------------------------------------------------------------------
*/

#include	"aa.h"
#include	"aakernel.h"

#include	"stm32h7xx_ll_rcc.h"
#include	"stm32h7xx_ll_system.h"
#include	"stm32h7xx_ll_pwr.h"
#include	"stm32h7xx_ll_utils.h"
#include	"stm32h7xx_ll_bus.h"
#include	"stm32h7xx_ll_crs.h"

static	void   Error_Handler	(void) ;

// ----------------------------------------------------------------------------
//	SystemClock_Config() may be generated by STM32CubeMX to configure the clock in accordance with your needs
//	You can use CubeMX to generate the LL code, and copy SystemClock_Config() here.

//	This function must:
//		Not initialize SysTick
//		Initialize peripheral clocks
//		Set TIMPRE if requested

// ----------------------------------------------------------------------------
#if (defined STM32H743xx)
//	Use 8 MHz HSE bypass as system clock source, system clock is 480 MHz
//	U(S)ART 1, 2, 3, 4, 5, 6, 7, 8 and LPUART1 clocks are 48 MHz (115200 bauds with 0.2% error, allows 12 Mbauds)
//	SPIs clocks are 80 MHz
//	I2C clocks are 120 MHz
//	USB clock 48 MHz from PLLQ3. Alternative: HSI48+CRS+SOF doesn't work see errata sheet.

void SystemClock_Config (void)
{
	LL_FLASH_SetLatency(LL_FLASH_LATENCY_4);

	while(LL_FLASH_GetLatency()!= LL_FLASH_LATENCY_4)
	{
	}
	LL_PWR_ConfigSupply(LL_PWR_LDO_SUPPLY);
	LL_PWR_SetRegulVoltageScaling(LL_PWR_REGU_VOLTAGE_SCALE0);

	// Start HSI 	(MCO test + USB)
	LL_RCC_HSI_Enable();
	while(LL_RCC_HSI_IsReady() != 1)
	{
	}
	LL_RCC_HSI_SetCalibTrimming(32);
	LL_RCC_HSI_SetDivider(LL_RCC_HSI_DIV1);
	LL_RCC_HSI48_Enable();

	// Enable CSI 	(MCO test)
	LL_RCC_CSI_Enable();
	while(LL_RCC_CSI_IsReady() != 1)
	{
	}

	// Enable HSI 	(MCO test)
	LL_RCC_HSI_Enable();
	while(LL_RCC_HSI_IsReady() != 1)
	{
	}
	LL_RCC_HSI_SetCalibTrimming(32);
	LL_RCC_HSI_SetDivider(LL_RCC_HSI_DIV1);
/*
	// Enable LSE 	(MCO test)
	LL_PWR_EnableBkUpAccess();
	LL_RCC_ForceBackupDomainReset();
	LL_RCC_ReleaseBackupDomainReset();
	LL_RCC_LSE_SetDriveCapability(LL_RCC_LSEDRIVE_LOW);
	LL_RCC_LSE_Enable();
	while(LL_RCC_LSE_IsReady() != 1)
	{
	}
*/
	// Enable HSE
	LL_RCC_HSE_EnableBypass();
	LL_RCC_HSE_Enable();
	while(LL_RCC_HSE_IsReady() != 1)
	{
	}

	LL_RCC_PLL_SetSource(LL_RCC_PLLSOURCE_HSE);
	LL_RCC_PLL1P_Enable();
	LL_RCC_PLL1Q_Enable();
	LL_RCC_PLL1R_Enable();
	LL_RCC_PLL1_SetVCOInputRange(LL_RCC_PLLINPUTRANGE_2_4);
	LL_RCC_PLL1_SetVCOOutputRange(LL_RCC_PLLVCORANGE_WIDE);
	LL_RCC_PLL1_SetM(4);
	LL_RCC_PLL1_SetN(480);
	LL_RCC_PLL1_SetP(2);
	LL_RCC_PLL1_SetQ(12);
	LL_RCC_PLL1_SetR(8);
	LL_RCC_PLL1_Enable();

	// Wait till PLL is ready
	while(LL_RCC_PLL1_IsReady() != 1)
	{
	}
///*
	LL_RCC_PLL2Q_Enable();
	LL_RCC_PLL2_SetVCOInputRange(LL_RCC_PLLINPUTRANGE_2_4);
	LL_RCC_PLL2_SetVCOOutputRange(LL_RCC_PLLVCORANGE_MEDIUM);
	LL_RCC_PLL2_SetM(4);
	LL_RCC_PLL2_SetN(80);
	LL_RCC_PLL2_SetP(2);
	LL_RCC_PLL2_SetQ(2);
	LL_RCC_PLL2_SetR(2);
	LL_RCC_PLL2_Enable();

	// Wait till PLL is ready
	while(LL_RCC_PLL2_IsReady() != 1)
	{
	}
//*/
	LL_RCC_PLL3P_Enable();
	LL_RCC_PLL3Q_Enable();
	LL_RCC_PLL3_SetVCOInputRange(LL_RCC_PLLINPUTRANGE_2_4);
	LL_RCC_PLL3_SetVCOOutputRange(LL_RCC_PLLVCORANGE_MEDIUM);
	LL_RCC_PLL3_SetM(4);
	LL_RCC_PLL3_SetN(96);
	LL_RCC_PLL3_SetP(2);
	LL_RCC_PLL3_SetQ(4);
	LL_RCC_PLL3_SetR(2);
	LL_RCC_PLL3_Enable();

	// Wait till PLL is ready
	while(LL_RCC_PLL3_IsReady() != 1)
	{
  	}

	// Intermediate AHB prescaler 2 when target frequency clock is higher than 80 MHz
	LL_RCC_SetAHBPrescaler(LL_RCC_AHB_DIV_2);

	LL_RCC_SetSysClkSource(LL_RCC_SYS_CLKSOURCE_PLL1);
	while(LL_RCC_GetSysClkSource() != LL_RCC_SYS_CLKSOURCE_STATUS_PLL1)
	{
	}

	LL_RCC_SetSysPrescaler(LL_RCC_SYSCLK_DIV_1);
	LL_RCC_SetAHBPrescaler(LL_RCC_AHB_DIV_2);
	LL_RCC_SetAPB1Prescaler(LL_RCC_APB1_DIV_2);
	LL_RCC_SetAPB2Prescaler(LL_RCC_APB2_DIV_2);
	LL_RCC_SetAPB3Prescaler(LL_RCC_APB3_DIV_2);
	LL_RCC_SetAPB4Prescaler(LL_RCC_APB4_DIV_2);

	LL_RCC_SetUSBClockSource(LL_RCC_USB_CLKSOURCE_PLL3Q);

	LL_RCC_SetI2CClockSource(LL_RCC_I2C123_CLKSOURCE_PCLK1);
	LL_RCC_SetI2CClockSource(LL_RCC_I2C4_CLKSOURCE_PCLK4);
	LL_RCC_SetSPIClockSource(LL_RCC_SPI123_CLKSOURCE_PLL1Q);
	LL_RCC_SetSPIClockSource(LL_RCC_SPI45_CLKSOURCE_PCLK2);
	LL_RCC_SetSPIClockSource(LL_RCC_SPI6_CLKSOURCE_PCLK4);
	LL_RCC_SetUSARTClockSource(LL_RCC_USART16_CLKSOURCE_PLL3Q);
	LL_RCC_SetUSARTClockSource(LL_RCC_USART234578_CLKSOURCE_PLL3Q);
	LL_RCC_SetLPUARTClockSource(LL_RCC_LPUART1_CLKSOURCE_PLL3Q);

    // Set TIMPRE
	RCC->CFGR |= RCC_CFGR_TIMPRE ;
}

#endif	// STM32H743xx

// ----------------------------------------------------------------------------
#if (defined STM32H723xx)
//	Use 8 MHz HSE bypass as system clock source, system clock is 480 MHz
//	U(S)ART 2, 3, 4, 5, 7, 8 clock is 120 MHz (115200 bauds with 0.1% error, allows 12 Mbauds)
//	TIMx clocks are 240 MHz
//	USB 48 MHz from PLL1Q (HSI48 requires a special Clock Recovery System (CRS) to be used as USB clock)

void SystemClock_Config(void)
{
  LL_FLASH_SetLatency(LL_FLASH_LATENCY_3);
  while(LL_FLASH_GetLatency()!= LL_FLASH_LATENCY_3)
  {
  }
  LL_PWR_ConfigSupply(LL_PWR_LDO_SUPPLY);
  LL_PWR_SetRegulVoltageScaling(LL_PWR_REGU_VOLTAGE_SCALE0);
  LL_RCC_HSE_EnableBypass();
  LL_RCC_HSE_Enable();

   /* Wait till HSE is ready */
  while(LL_RCC_HSE_IsReady() != 1)
  {

  }

  LL_RCC_HSI48_Enable();
  while(LL_RCC_HSI48_IsReady() != 1)
  {
  }

  LL_RCC_PLL_SetSource(LL_RCC_PLLSOURCE_HSE);
  LL_RCC_PLL1P_Enable();
  LL_RCC_PLL1R_Enable();
  LL_RCC_PLL1_SetVCOInputRange(LL_RCC_PLLINPUTRANGE_8_16);
  LL_RCC_PLL1_SetVCOOutputRange(LL_RCC_PLLVCORANGE_WIDE);
  LL_RCC_PLL1_SetM(1);
  LL_RCC_PLL1_SetN(60);
  LL_RCC_PLL1_SetP(1);
  LL_RCC_PLL1_SetQ(10);
  LL_RCC_PLL1_SetR(2);
  LL_RCC_PLL1_Enable();

  /* Wait till PLL is ready */
  while(LL_RCC_PLL1_IsReady() != 1)
  {
  }

   /* Intermediate AHB prescaler 2 when target frequency clock is higher than 80 MHz */
  LL_RCC_SetAHBPrescaler(LL_RCC_AHB_DIV_2);

  LL_RCC_SetSysClkSource(LL_RCC_SYS_CLKSOURCE_PLL1);

  /* Wait till System clock is ready */
  while(LL_RCC_GetSysClkSource() != LL_RCC_SYS_CLKSOURCE_STATUS_PLL1)
  {

  }
  LL_RCC_SetSysPrescaler(LL_RCC_SYSCLK_DIV_1);
  LL_RCC_SetAHBPrescaler(LL_RCC_AHB_DIV_2);
  LL_RCC_SetAPB1Prescaler(LL_RCC_APB1_DIV_2);
  LL_RCC_SetAPB2Prescaler(LL_RCC_APB2_DIV_2);
  LL_RCC_SetAPB3Prescaler(LL_RCC_APB3_DIV_2);
  LL_RCC_SetAPB4Prescaler(LL_RCC_APB4_DIV_2);

/*
  LL_RCC_PLL2P_Enable();
  LL_RCC_PLL2_SetVCOInputRange(LL_RCC_PLLINPUTRANGE_4_8);
  LL_RCC_PLL2_SetVCOOutputRange(LL_RCC_PLLVCORANGE_WIDE);
  LL_RCC_PLL2_SetM(2);
  LL_RCC_PLL2_SetN(60);
  LL_RCC_PLL2_SetP(2);
  LL_RCC_PLL2_SetQ(2);
  LL_RCC_PLL2_SetR(2);
  LL_RCC_PLL2_Enable();

  // Wait till PLL is ready
  while(LL_RCC_PLL2_IsReady() != 1)
  {
  }
*/
	// Enable CRS to trim HSI48 oscillator with 1 kHz USB SOF (Start Of Frame)
	LL_APB1_GRP2_EnableClock (RCC_APB1HENR_CRSEN) ;
	LL_CRS_ConfigSynchronization (	LL_CRS_HSI48CALIBRATION_DEFAULT,
									LL_CRS_ERRORLIMIT_DEFAULT,
									__LL_CRS_CALC_CALCULATE_RELOADVALUE (48000000, 1000),
									LL_CRS_SYNC_DIV_1 | LL_CRS_SYNC_SOURCE_USB | LL_CRS_SYNC_POLARITY_RISING) ;
	CRS->CR |= CRS_CR_AUTOTRIMEN | CRS_CR_CEN ;	// Set auto trim and enable CRS
	LL_RCC_SetUSBClockSource(LL_RCC_USB_CLKSOURCE_HSI48) ;
}
#endif	// STM32H723xx

// ----------------------------------------------------------------------------
// ----------------------------------------------------------------------------
//	The purpose of this function is to provide a prologue and an epilogue to SystemClock_Config().

void	bspSystemClockInit ()
{
	// These initialization may be required if SystemClock_Config() configure LSE
	LL_APB4_GRP1_EnableClock(LL_APB4_GRP1_PERIPH_SYSCFG);
//	LL_APB1_GRP1_EnableClock (LL_APB1_GRP1_PERIPH_PWR) ;	// The PWR block is always enabled on the H7

	SystemClock_Config () ;

	// Stop SysTick if it is started by SystemClock_Config()
	SysTick->CTRL = 0 ;
}

// ----------------------------------------------------------------------------
//	This function is used by CubeMX generated code

BSP_ATTR_USED static	void   Error_Handler	(void)
{
	BSP_DEBUG_BKPT () ;
	while (1)
	{
	}
}

// ----------------------------------------------------------------------------
