
/*--------------------------------------------------------------------------
/*
 * Memory Spaces Definitions.
 *
 * Update for a specific board. 
 *   FLASH.ORIGIN : starting address of flash
 *   FLASH.LENGTH : length of flash
 *   RAM.ORIGIN   : starting address of main RAM
 *   RAM.LENGTH   : length of main RAM
 *
 * The values below can be addressed in linker scripts
 * using functions like 'ORIGIN(RAM)' or 'LENGTH(RAM)'.
 */

/* Memory definitions for  STM32H723
 * Adjust your amount of FLASH
 *
 * Can execute code from ITCM
 * Can execute code from RAM_D2 (only SRAM1, 16K)
 *
 * RAM_D1 is 128K AXI SRAM + 192K ITCM (Factory default)
 *  To change ITCM size use the option FLASH_OPTSR2_PRG register
 * RAM_D2 is SRAM1(16K) + SRAM2(16K)
 * RAM_D3 is SRAM4(16K)
 */

MEMORY
{
	ITCM    (xrw) : ORIGIN = 0x00000000, LENGTH = 64K
	FLASH    (rx) : ORIGIN = 0x08000000, LENGTH = 1024K
	FLASHB2  (rx) : ORIGIN = 0x08100000, LENGTH = 0K
	DTCM     (rw) : ORIGIN = 0x20000000, LENGTH = 128K
	RAM_D1  (xrw) : ORIGIN = 0x24000000, LENGTH = 320K
	RAM_D2  (xrw) : ORIGIN = 0x30000000, LENGTH = 32K
	RAM_D3   (rw) : ORIGIN = 0x38000000, LENGTH = 16K
	BKPRAM   (rw) : ORIGIN = 0x38800000, LENGTH = 4K

	EXTMEMB0 (rx) : ORIGIN = 0x00000000, LENGTH = 0
	EXTMEMB1 (rx) : ORIGIN = 0x00000000, LENGTH = 0
	EXTMEMB2 (rx) : ORIGIN = 0x00000000, LENGTH = 0
	EXTMEMB3 (rx) : ORIGIN = 0x00000000, LENGTH = 0
}

INCLUDE ../sections.ld