
/*--------------------------------------------------------------------------
/*
 * Memory Spaces Definitions.
 *
 * Update for a specific board. 
 *   FLASH.ORIGIN : starting address of flash
 *   FLASH.LENGTH : length of flash
 *   RAM.ORIGIN   : starting address of main RAM
 *   RAM.LENGTH   : length of main RAM
 *
 * The values below can be addressed in linker scripts
 * using functions like 'ORIGIN(RAM)' or 'LENGTH(RAM)'.
 */

/* Memory definitions for  STM32H750xx
 *
 * Can execute code from ITCM
 * Can execute code from RAM_D2
 *
 * RAM_D1 is AXI SRAM
 * RAM_D2 is SRAM1(128) + SRAM2(128) + SRAM3(32)
 * RAM_D3 is SRAM4(64)
 */

MEMORY
{
	ITCM    (xrw) : ORIGIN = 0x00000000, LENGTH = 64K
	FLASH    (rx) : ORIGIN = 0x08000000, LENGTH = 128K
	FLASHB2  (rx) : ORIGIN = 0x08100000, LENGTH = 0K
	DTCM     (rw) : ORIGIN = 0x20000000, LENGTH = 128K
	RAM_D1  (xrw) : ORIGIN = 0x24000000, LENGTH = 512K
	RAM_D2  (xrw) : ORIGIN = 0x30000000, LENGTH = 288K
	RAM_D3  (xrw) : ORIGIN = 0x38000000, LENGTH = 64K
	BKPRAM   (rw) : ORIGIN = 0x38800000, LENGTH = 4K

	EXTMEMB0 (rx) : ORIGIN = 0x00000000, LENGTH = 0
	EXTMEMB1 (rx) : ORIGIN = 0x00000000, LENGTH = 0
	EXTMEMB2 (rx) : ORIGIN = 0x00000000, LENGTH = 0
	EXTMEMB3 (rx) : ORIGIN = 0x00000000, LENGTH = 0
}

INCLUDE ../sections.ld