/*
----------------------------------------------------------------------

	AdAstra - Real Time Kernel

	Alain Chebrou

	testexti.c	EXTI and software interrupt test

	When		Who	What
	02/09/18	ac	Creation
	02/05/21	ac	Individual EXTI lines callback

----------------------------------------------------------------------
*/

#include "aa.h"
#include "aalogmes.h"

#include "extibasic.h"

#include "test.h"

//----------------------------------------------------------------------
// EXTI lines description

#define	EXTI_SWI_LINE	EXTI_ETH_WKUP

#define	EXTI_GPIO_PORT	'C'
#define	EXTI_GPIO_LINE	13

static	uint32_t		swiCount, itCount ;

//----------------------------------------------------------------------
//	Using an EXTI line X the user have to define the function extiCallbackX()
//	It is called by the EXTI interrupt routine.
//	The interrupt bit in PR register is cleared prior to the call of the callback

//	In this SWI test the function checks that there has been as many callback calls as there are software interrupt requests.
//	And toggle the a LED

void EXTI_CALLBACK (EXTI_SWI_LINE) (uint32_t flags)
{
	(void) flags ;

	itCount++ ;
	if (swiCount == itCount)
	{
		aaLogMes ("exti %u: %u %u  OK\n", EXTI_SWI_LINE, swiCount, itCount, 0, 0) ;
	}
	else
	{
		aaLogMes ("exti %u: %u %u  KO ***\n", EXTI_SWI_LINE, swiCount, itCount, 0, 0) ;
	}
	bspToggleOutput (BSP_LED2) ;
}

void EXTI_CALLBACK (EXTI_GPIO_LINE) (uint32_t flags)
{
	(void) flags ;	// useful when aaLogMes is not defined

	aaLogMes ("exti %u: R=%u  F=%u  OK\n", EXTI_GPIO_LINE,
			((flags & EXTI_FLAG_RISING) != 0) ? 1 : 0,
			((flags & EXTI_FLAG_FALLING) != 0) ? 1 : 0,
			0, 0) ;
}

//----------------------------------------------------------------------
//	Configure EXTI for 2 interrupts:
//		one physical EXTI interrupt on PC13 (User button of NUCLEO LQFP144)
//		one software interrupt on line EXTI_SWI_LINE

void	swiTest (void)
{
	gpioPinDesc_t pinDesc ;

	// Configure hardware external interrupt
	pinDesc.port	= EXTI_GPIO_PORT ;
	pinDesc.pin		= EXTI_GPIO_LINE ;
	pinDesc.af		= 0 ;
	pinDesc.flags	= AA_GPIO_PULL_NO ;		// No pull up/down on NUCLEO button !!!

	// The button GPIO is already configured by bspboard.c, so use EXTI_FLAG_GPIO_NOCONF
	extiInitGpio (& pinDesc, BSP_IRQPRIOMAX_MINUS(2), EXTI_FLAG_GPIO_NOCONF | EXTI_FLAG_RISING | EXTI_FLAG_INTR) ;

	// Configure software interrupt
	extiInitSwi (EXTI_SWI_LINE, BSP_IRQPRIOMAX_MINUS(2)) ;

	aaTaskDelay (10) ;

	swiCount = 0 ;
	itCount  = 0 ;
	while (1)
	{
		if (aaCheckGetChar () != 0)
		{
			break ;		// Test cancelled by the user
		}

		aaTaskDelay (bspGetTickRate ()) ;
		swiCount++ ;
		extiSwiTrigger (EXTI_SWI_LINE)  ;
	}

	extiResetLine (EXTI_SWI_LINE) ;
	extiResetLine (EXTI_GPIO_LINE) ;

	while (aaCheckGetChar () != 0)
	{
		(void) aaGetChar () ;
	}
}

//----------------------------------------------------------------------
